@@ -24,7 +24,7 @@ except Exception:
 
 from pilot.info import infosys
 from pilot.common.exception import PilotException, ErrorCodes, SizeTooLarge, NoLocalSpace, ReplicasNotFound
-from pilot.util.auxiliary import get_memory_usage, extract_memory_usage_value
+from pilot.util.auxiliary import show_memory_usage
 from pilot.util.config import config
 from pilot.util.filehandling import calculate_checksum, write_json
 from pilot.util.math import convert_mb_to_b
@@ -231,17 +231,13 @@ class StagingClient(object):
         logger = self.logger
         xfiles = []
 
-        _ec, _stdout, _stderr = get_memory_usage(os.getpid())
-        logger.debug('current pilot memory usage (resolve_replicas: start):\n%s' % _stdout)
-        logger.debug('extracted pilot memory usage: %d kB' % extract_memory_usage_value(_stdout))
+        show_memory_usage()
 
         for fdat in files:
             ## skip fdat if need for further workflow (e.g. to properly handle OS ddms)
             xfiles.append(fdat)
 
-        _ec, _stdout, _stderr = get_memory_usage(os.getpid())
-        logger.debug('current pilot memory usage (resolve_replicas: added fspecs):\n%s' % _stdout)
-        logger.debug('extracted pilot memory usage: %d kB' % extract_memory_usage_value(_stdout))
+        show_memory_usage()
 
         if not xfiles:  # no files for replica look-up
             return files
@@ -250,9 +246,7 @@ class StagingClient(object):
         from rucio.client import Client
         c = Client()
 
-        _ec, _stdout, _stderr = get_memory_usage(os.getpid())
-        logger.debug('current pilot memory usage (resolve_replicas: imported rucio):\n%s' % _stdout)
-        logger.debug('extracted pilot memory usage: %d kB' % extract_memory_usage_value(_stdout))
+        show_memory_usage()
 
         location = self.detect_client_location()
         if not location:
@@ -275,9 +269,7 @@ class StagingClient(object):
         except Exception as e:
             raise PilotException("Failed to get replicas from Rucio: %s" % e, code=ErrorCodes.RUCIOLISTREPLICASFAILED)
 
-        _ec, _stdout, _stderr = get_memory_usage(os.getpid())
-        logger.debug('current pilot memory usage (resolve_replicas: called list_replicas):\n%s' % _stdout)
-        logger.debug('extracted pilot memory usage: %d kB' % extract_memory_usage_value(_stdout))
+        show_memory_usage()
 
         replicas = list(replicas)
         logger.debug("replicas received from Rucio: %s" % replicas)
@@ -317,9 +309,7 @@ class StagingClient(object):
                 logger.info("filesize and checksum verification done")
                 self.trace_report.update(clientState="DONE")
 
-        _ec, _stdout, _stderr = get_memory_usage(os.getpid())
-        logger.debug('current pilot memory usage (resolve_replicas: added replicas):\n%s' % _stdout)
-        logger.debug('extracted pilot memory usage: %d kB' % extract_memory_usage_value(_stdout))
+        show_memory_usage()
 
         logger.info('Number of resolved replicas:\n' +
                     '\n'.join(["lfn=%s: replicas=%s, is_directaccess=%s"
@@ -506,8 +496,7 @@ class StagingClient(object):
                 self.logger.debug('kwargs=%s' % str(kwargs))
                 result = self.transfer_files(copytool, remain_files, activity, **kwargs)
                 self.logger.debug('transfer_files() using copytool=%s completed with result=%s' % (copytool, str(result)))
-                ec, stdout, stderr = get_memory_usage(os.getpid())
-                self.logger.debug('current pilot memory usage (after transfer_files())\n%s' % stdout)
+                show_memory_usage()
                 break
             except PilotException as e:
                 self.logger.warning('failed to transfer_files() using copytool=%s .. skipped; error=%s' % (copytool, e))
@@ -861,8 +850,7 @@ class StageInClient(StagingClient):
         # verify file sizes and available space for stage-in
         self.check_availablespace(remain_files)
 
-        ec, stdout, stderr = get_memory_usage(os.getpid())
-        self.logger.debug('current pilot memory usage (just before stage-in)\n%s' % stdout)
+        show_memory_usage()
 
         # add the trace report
         kwargs['trace_report'] = self.trace_report
